<?php
namespace Teknisa\SM\Service;

class ReplicacaoParceiroService {
    
    const PROSPECT = 'PROSPECT';
    const LEAD     = 'CANDIDATO';
    const PARCEIRO = 'PARCEIRO';
    
    protected $replicacaoFactory;
    
    public function __construct($replicacaoFactory){
        $this->replicacaoFactory = $replicacaoFactory;
    }
    
    /**
     * Replica os dados do novo registro
     * para o Lead.
     * 
     * @param $nrparcnegocio Parceiro salvo
     * @param $tela          Tela em que o registro foi salvo (PARCEIRO ou PROSPECT)
     * 
     * @return string
     * @throws \Exception
    */
    public function replicaLead($nrparcnegocio, $tela){
        try{
            $dadosAtualizados = $this->montaDados($tela, $nrparcnegocio);
            $this->replicacaoFactory->replicaLead($nrparcnegocio, $dadosAtualizados); 
            return 'Lead Replicado; ';
        }catch(\Exception $e){
            throw new \Exception('Erro ao replicar o Lead: '.$e->getMessage());
        }
    }
    
    /**
     * Replica os dados do novo registro
     * para o Parceiro.
     * 
     * @param $nrparcnegocio Parceiro salvo
     * @param $tela          Tela em que o registro foi salvo (CANDIDATO(Lead) ou PROSPECT)
     * 
     * @return string
     * @throws \Exception
    */
    public function replicaParceiro($nrparcnegocio, $tela){
        try{
            $dadosAtualizados = $this->montaDados($tela, $nrparcnegocio);
            $this->replicacaoFactory->replicaParceiro($nrparcnegocio, $dadosAtualizados);   
            return 'Parceiro Replicado; ';
        }catch(\Exception $e){
            throw new \Exception('Erro ao replicar o Parceiro: '.$e->getMessage());
        }
    }
    
    /**
     * Replica os dados do novo registro
     * para o Prospect.
     * 
     * @param $nrparcnegocio Parceiro salvo
     * @param $tela          Tela em que o registro foi salvo (CANDIDATO(Lead) ou PARCEIRO)
     * 
     * @return string
     * @throws \Exception
    */
    public function replicaProspect($nrparcnegocio, $tela){
        try{
            $dadosAtualizados = $this->montaDados($tela, $nrparcnegocio);
            $this->replicacaoFactory->replicaProspect($nrparcnegocio, $dadosAtualizados); 
            return 'Prospect Replicado; ';
        }catch(\Exception $e){
            throw new \Exception('Erro ao replicar o Prospect: '.$e->getMessage());
        }
    }
    
    /**
     * Monta um array com os dados atualizados do
     * parceiro salvo.
     * 
     * @param $tela          Tela em que o registro foi salvo (CANDIDATO(Lead), PARCEIRO ou PROSPECT)
     * @param $nrparcnegocio Parceiro salvo
     * 
     * @return array
     * @throws \Exception
    */
    private function montaDados($tela, $nrparcnegocio){
        try{
            $dadosAtualizados = array(
                'RAZAO'     => null,
                'FANTASIA'  => null,
                'INSCRICAO' => null,
                'TIPOINSCR' => null,
                'SEGMENTO'  => null,
                'STATUS'    => null,
                'OPERADOR'  => null,
                'N_FUNC'    => null,
                'MDDIVULG'  => null,
                'RAMOATIV'  => null,
                'TIPOATIV'  => null,
            );
            switch($tela) {
                case self::PROSPECT:
                    $this->replicacaoFactory->getDadosProspect($dadosAtualizados, $nrparcnegocio);
                    break;
                case self::LEAD:
                    $this->replicacaoFactory->getDadosLead($dadosAtualizados, $nrparcnegocio);
                    break;
                case self::PARCEIRO:
                    $this->replicacaoFactory->getDadosParceiro($dadosAtualizados, $nrparcnegocio);
                    break;
            }
            return $dadosAtualizados;
        }catch(\Exception $e){
            throw new \Exception('Erro ao montar os dados atualizados: '.$e->getMessage());
        }
    }

}